package mi.hdm.shoppingList;

import mi.hdm.exceptions.InvalidIngredientException;
import mi.hdm.recipes.Ingredient;
import mi.hdm.recipes.IngredientManager;
import mi.hdm.recipes.NutritionCalculator;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

/**
 * Shopping list that the user can add ingredients to. The elements on the list can be marked as done or undone.
 */
public class ShoppingList {
    //TODO: implement class

    private static final Logger log = LogManager.getLogger(ShoppingList.class);
    private final Map<Ingredient, Boolean> list;

    private static final ShoppingList shoppingList = new ShoppingList();

    private ShoppingList() {
        list = new HashMap<Ingredient, Boolean>();
    }

    public static ShoppingList getInstance() {
        return shoppingList;
    }

    public void clear() {
        list.clear();
        log.info("ShoppingList cleared successfully.");
    }

    public void markDone(Ingredient in) {
        list.put(in, true);
        log.info("Ingredient {} marked as done", in);
    }
    public void markDone(String name){
        Ingredient in = getIngredientByName(name).orElseThrow(() -> new InvalidIngredientException("No ingredient with name " + name));;
        markDone(in);
    }

    public void markUndone(int id) {}

    public Map<Ingredient, Boolean> getList() {
        return list;
    }

    private Optional<Ingredient> getIngredientByName(String name) {
        for (final Ingredient i : list.keySet()) {
            if (name.equals(i.getName())) {
                return Optional.of(i);
            }
        }
        return Optional.empty();
    }
}
